@@ -226,7 +226,11 @@ void TouchpadDisabler::mousePlugged()
 
 void TouchpadDisabler::showNotification(const QString &name, const QString &text)
 {
-    KNotification::event(name, text, QPixmap(), //Icon is specified in .notifyrc
+    if (m_notification) {
+        m_notification->close();
+    }
+
+    m_notification = KNotification::event(name, text, QPixmap(), //Icon is specified in .notifyrc
                          0,
                          KNotification::CloseOnTimeout,
                          "kcm_touchpad"); // this has to match the name of the .notifyrc file
